# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration


class Migration(SchemaMigration):
    def forwards(self, orm):
        # Adding model 'UploadedFile'
        db.create_table(u'django_file_form_uploadedfile', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('created', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now)),
            ('uploaded_file', self.gf('django.db.models.fields.files.FileField')(max_length=255)),
            ('field_name', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('file_id', self.gf('django.db.models.fields.CharField')(max_length=40)),
            ('form_id', self.gf('django.db.models.fields.CharField')(max_length=40)),
        ))
        db.send_create_signal(u'django_file_form', ['UploadedFile'])

    def backwards(self, orm):
        # Deleting model 'UploadedFile'
        db.delete_table(u'django_file_form_uploadedfile')

    models = {
        u'django_file_form.uploadedfile': {
            'Meta': {'object_name': 'UploadedFile'},
            'created': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'field_name': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'file_id': ('django.db.models.fields.CharField', [], {'max_length': '40'}),
            'form_id': ('django.db.models.fields.CharField', [], {'max_length': '40'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'uploaded_file': ('django.db.models.fields.files.FileField', [], {'max_length': '255'})
        }
    }

    complete_apps = ['django_file_form']


from setuptools import setup, find_packages


version = '0.1.4.4'

setup(
    name='django-file-form',
    version=version,
    packages=find_packages(),
    license='Apache License, Version 2.0',
    include_package_data=True,
    zip_safe=False,
    author='Marco Braak',
    author_email='mbraak@ridethepony.nl',
    description='Django-file-form helps you to write forms with a pretty ajax upload',
    install_requires=['ajaxuploader==0.3.0.3', 'six', 'path.py'],
    dependency_links=[
        'https://github.com/mbraak/django-ajax-uploader/archive/0.3.0.3.tar.gz#egg=ajaxuploader-0.3.0.3',
    ]
)



# -*- coding: utf-8 -*-
from south.db import db
from south.v2 import SchemaMigration


class Migration(SchemaMigration):
    def forwards(self, orm):
        # Adding field 'UploadedFile.original_filename'
        db.add_column(u'django_file_form_uploadedfile', 'original_filename',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=255),
                      keep_default=False)

    def backwards(self, orm):
        # Deleting field 'UploadedFile.original_filename'
        db.delete_column(u'django_file_form_uploadedfile', 'original_filename')

    models = {
        u'django_file_form.uploadedfile': {
            'Meta': {'object_name': 'UploadedFile'},
            'created': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'field_name': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'file_id': ('django.db.models.fields.CharField', [], {'max_length': '40'}),
            'form_id': ('django.db.models.fields.CharField', [], {'max_length': '40'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'original_filename': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'uploaded_file': ('django.db.models.fields.files.FileField', [], {'max_length': '255'})
        }
    }

    complete_apps = ['django_file_form']